"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const slack_service_1 = require("../slack.service");
const fixtures_1 = require("./fixtures");
const nock = require("nock");
describe('webhook', () => {
    let service;
    let output;
    const baseUrl = 'https://example.com';
    beforeEach(() => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        output = jest.fn();
        const app = yield (0, fixtures_1.createApp)({
            type: 'webhook',
            webhookOptions: { url: `${baseUrl}/webhook` },
        });
        service = app.get(slack_service_1.SlackService);
    }));
    it('must send requests to API', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const scope = nock(baseUrl, { encodedQueryParams: true })
            .post('/webhook', {
            text: 'hello-world',
        })
            .reply(200, 'ok');
        yield service.postMessage({ text: 'hello-world' });
        scope.done();
    }));
    it('Should throw when request fails', () => {
        nock(baseUrl, { encodedQueryParams: true })
            .post('/webhook', {
            text: 'hello-world',
        })
            .reply(500, 'fail');
        return service
            .postMessage({ text: 'hello-world' })
            .catch(error => expect(error).toMatchInlineSnapshot(`[Error: Could not send request to Slack Webhook: fail]`));
    });
});
